----------------------------------------------------------------------
----                                                              ----
---- MC68K family compatible IP Core                              ----
----                                                              ----
---- This file is part of the SUSKA ATARI clone project.          ----
---- http://www.experiment-s.de                                   ----
----                                                              ----
---- Description:                                                 ----
---- This model provides an opcode and bus timing compatible ip   ----
---- core compared to Motorola's MC68851 memory management unit.  ----
----                                                              ----
---- This file is the package file of this ip core.               ----
----                                                              ----
----                                                              ----
----                                                              ----
----                                                              ----
---- Author(s):                                                   ----
---- - Wolfgang Foerster, wf@experiment-s.de; wf@inventronik.de   ----
----                                                              ----
----------------------------------------------------------------------
----                                                              ----
---- Copyright (C) 2007 Wolfgang Foerster                         ----
----                                                              ----
---- This source file may be used and distributed without         ----
---- restriction provided that this copyright statement is not    ----
---- removed from the file and that any derivative work contains  ----
---- the original copyright notice and the associated disclaimer. ----
----                                                              ----
---- This source file is free software; you can redistribute it   ----
---- and/or modify it under the terms of the GNU Lesser General   ----
---- Public License as published by the Free Software Foundation; ----
---- either version 2.1 of the License, or (at your option) any   ----
---- later version.                                               ----
----                                                              ----
---- This source is distributed in the hope that it will be       ----
---- useful, but WITHOUT ANY WARRANTY; without even the implied   ----
---- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR      ----
---- PURPOSE. See the GNU Lesser General Public License for more  ----
---- details.                                                     ----
----                                                              ----
---- You should have received a copy of the GNU Lesser General    ----
---- Public License along with this source; if not, download it   ----
---- from http://www.gnu.org/licenses/lgpl.html                   ----
----                                                              ----
----------------------------------------------------------------------
-- 
-- Revision History
-- 
-- Revision 2K7B  2007/12/24 WF
--   Initial Release.

library ieee;
use ieee.std_logic_1164.all;

package WF68851IP_PKG is
component WF68851IP_BUS_INTERFACE
	port (
		CLK					: in bit;
		RESETn				: in bit;
		RESET_INn			: in bit;
		RESET_OUT_EN		: out bit;
		RESET_CPUn			: out bit;
		RESET_EN			: in bit;
		RESET_RDY			: out bit;
		DATA_PORT_IN		: in std_logic_vector(31 downto 0);
		DATA_PORT_OUT		: out std_logic_vector(31 downto 0);
		DATA_2_PORT			: in std_logic_vector(31 downto 0);
		DATA_2_CORE			: out std_logic_vector(31 downto 0);
		OPCODE_DATA			: out std_logic_vector(15 downto 0);
		SEL_BUFF_A			: in bit;
		SEL_BUFF_B			: in bit;
		BUFFER_A			: out std_logic_vector(31 downto 0);
		BUFFER_B			: out std_logic_vector(31 downto 0);
		RD_BUS				: in bit;
		WR_BUS				: in bit;
		A0					: in std_logic;
		A1					: in std_logic;
		PC1					: in std_logic;
		OP_SIZE				: in CTRL_OP_SIZETYPE;
		OP_END				: in bit;
		RMC_OP				: in bit;
		EXEC_ABORT			: in bit;
		ADR_OFFS_CLR		: in bit;
		MOVEP				: in bit;
		ADR_OFFSET			: out std_logic_vector(5 downto 0);
		BUS_CTRL_RDY		: out bit;
		DATA_VALID			: out bit;
		DATA_PORT_EN		: out bit;
		BUS_EN				: out bit;
		DSACKn				: in bit_vector(1 downto 0);
		BERRn				: in bit;
		AVECn				: in bit;
		HALTn				: in std_logic;
		SIZE				: out std_logic_vector(1 downto 0);
		ASn					: out bit;
		DSn					: out bit;
		RWn					: out bit;
		RMCn				: out bit;
		BRn					: in bit;
		BGACKn				: in bit;
		BGn					: out bit;
		OPCODE_FETCH		: in bit;
		FLUSH_OPC_BUFF		: in bit
		);
end component;
end WF68KIP_PKG;
